@@ -6,7 +6,7 @@ from lark import Lark
 from .diagnostics import LIN_MASTER_REQUEST_FRAME_ID, LIN_SLAVE_RESPONSE_FRAME_ID, LinDiagnosticFrame, LinDiagnosticRequest, LinDiagnosticResponse
 from .schedule import AssignFrameIdEntry, AssignFrameIdRangeEntry, AssignNadEntry, ConditionalChangeNadEntry, DataDumpEntry, FreeFormatEntry, MasterRequestEntry, SaveConfigurationEntry, ScheduleTable, SlaveResponseEntry, UnassignFrameIdEntry, LinFrameEntry
 
-from .frame import LinEventTriggeredFrame, LinUnconditionalFrame
+from .frame import LinEventTriggeredFrame, LinSporadicFrame, LinUnconditionalFrame
 from .signal import LinSignal
 from .encoding import ASCIIValue, BCDValue, LinSignalEncodingType, LogicalValue, PhysicalValue, ValueConverter
 from .lin import LIN_VERSION_2_0, LIN_VERSION_2_1, LinVersion
@@ -24,7 +24,7 @@ def parse_ldf_to_dict(path: str, capture_comments: bool = False, encoding: str =
     :type encoding: str
     """
     comments = []
-    lark = os.path.join(os.path.dirname(__file__), 'grammars', 'ldf.lark')
+    lark = os.path.abspath(os.path.join(os.path.dirname(__file__), 'grammars', 'ldf.lark'))
     parser = Lark(grammar=open(lark), parser='lalr', lexer_callbacks={
         'C_COMMENT': comments.append,
         'CPP_COMMENT': comments.append
@@ -64,6 +64,7 @@ def parse_ldf(path: str, capture_comments: bool = False, encoding: str = None) -
     _populate_ldf_signals(json, ldf)
     _populate_ldf_frames(json, ldf)
     _populate_ldf_event_triggered_frames(json, ldf)
+    _populate_ldf_sporadic_frames(json, ldf)
     _populate_diagnostic_signals(json, ldf)
     _populate_diagnostic_frames(json, ldf)
     _populate_ldf_nodes(json, ldf)
@@ -133,6 +134,15 @@ def _populate_ldf_event_triggered_frames(json: dict, ldf: LDF):
             frames.append(ldf.get_unconditional_frame(a))
         ldf._event_triggered_frames[frame['name']] = LinEventTriggeredFrame(frame['frame_id'], frame['name'], frames)
 
+def _populate_ldf_sporadic_frames(json: dict, ldf: LDF):
+    if "sporadic_frames" not in json:
+        return
+    for frame in json['sporadic_frames']:
+        frames = []
+        for a in frame['frames']:
+            frames.append(ldf.get_unconditional_frame(a))
+        ldf._sporadic_frames[frame['name']] = LinSporadicFrame(frame['name'], frames)
+
 def _populate_ldf_nodes(json: dict, ldf: LDF):
     nodes = _require_key(json, 'nodes', 'Missing Nodes section.')
     if nodes.get('master'):
@@ -150,6 +160,9 @@ def _populate_ldf_nodes(json: dict, ldf: LDF):
                 node = LinSlave(slave)
                 node.lin_protocol = ldf.protocol_version
                 ldf._slaves[node.name] = node
+                if json.get('diagnostic_addresses') is not None and json['diagnostic_addresses'].get(node.name) is not None:
+                    node.initial_nad = json['diagnostic_addresses'][node.name]
+                    node.configured_nad = json['diagnostic_addresses'][node.name]
 
 def _create_ldf2x_node(node: dict, language_version: float):
     name = node['name']
@@ -191,7 +204,7 @@ def _populate_diagnostic_frames(json: dict, ldf: LDF):
                     raise ValueError(f"{frame['name']} references non existing signal {signal['signal']}")
                 signals[signal['offset']] = s
 
-            frame_obj = LinDiagnosticFrame(frame['frame_id'], frame['name'], 9, signals)
+            frame_obj = LinDiagnosticFrame(frame['frame_id'], frame['name'], 8, signals)
             ldf._diagnostic_frames[frame['name']] = frame_obj
             if frame['frame_id'] == LIN_MASTER_REQUEST_FRAME_ID:
                 ldf._master_request_frame = LinDiagnosticRequest(frame_obj)
